@@ -14,15 +14,15 @@ class HarvardDataverse2018General(e.DataSource):
     alaska_handler = attr.ib()
 
     def version(self):
-        return "1.5.0"
+        return "1.6.0"
 
     def description(self):
         return textwrap.dedent(
             """
-        Harvard Dataverse's 2018 dataset. This dataset contains information for most 2018 results
+            Harvard Dataverse's 2018 dataset. This dataset contains information for most 2018 results
 
-        It has some weird inconsistent data for New England, specifically CT, MA, NH, RI, VT.
-        """
+            It has some weird inconsistent data for New England, specifically CT, MA, NH, RI, VT.
+            """
         )
 
     def get_direct(self):
@@ -39,6 +39,12 @@ class HarvardDataverse2018General(e.DataSource):
         with zf.open("national-files/governor-wide.csv") as f:
             df_governor = e.to_csv(f.read().decode("utf-8"))
 
+        # Just manually fix the Angus King thing
+        df_senate.loc[df_senate.state == "ME", "dem"] += df_senate[
+            df_senate.state == "ME"
+        ]["other"]
+        df_senate.loc[df_senate.state == "ME", "other"] = 0
+
         df = pd.concat([df_house, df_senate, df_governor])
 
         df = pd.concat(
@@ -48,6 +54,8 @@ class HarvardDataverse2018General(e.DataSource):
             ]
         )
 
+        df["special"] = df.office == "US Senate Special Election"
+
         df = df.rename(
             columns={"dem": "votes_DEM", "rep": "votes_GOP", "other": "votes_other"}
         )
@@ -68,7 +76,7 @@ class HarvardDataverse2018General(e.DataSource):
         df = df[~((df.district == "statewide") & (df.office == "us house"))]
 
         agg = e.Aggregator(
-            grouped_columns=["county_fips", "district", "office"],
+            grouped_columns=["county_fips", "district", "office", "special"],
             aggregation_functions={
                 "votes_DEM": sum,
                 "votes_GOP": sum,
